import os
from lxml import objectify

class SDM:
    def __init__(self, sdmpath='.', bdfpath='.'):
        self.sdmpath = os.path.abspath(sdmpath)
        self.bdfpath = os.path.abspath(bdfpath)
        self.tables = {}  # These are the SDM Tables {name : root of the xml doc}
        self.bdffiles = []
        asdmtree = objectify.parse(sdmpath + '/ASDM.xml')
        self.asdm = asdmtree.getroot()

        # Load the SDM tables
        for table in self.asdm.Table:
            entityid = table.Entity.get('entityId')
            self.tables[table.Name] = buildtable(table.Name, self.sdmpath, entityid)
        # Load the BDF files
        bdffiletree = objectify.parse(sdmpath + '/Main.xml')
        bdfs = bdffiletree.getroot()
        for rw in bdfs.row:
            # XML Change
            if row.dataUID is not None:
                file = rw.dataUID.EntityRef.get('entityId')
            elif row.dataOid is not None:
                file = rw.dataOid.EntityRef.get('entityId')
            else:
                raise 'Invalid XML element'
            # for testing
            # self.bdffiles.append(os.path.join(bdfpath, file.replace(':///', '____').replace('/', '_') + '.loaded'))
            self.bdffiles.append(os.path.join(bdfpath, file.replace(':///', '____').replace('/', '_')))


def buildtable(name, path, entityid):
    filename = os.path.join(path, str(name))
    if os.path.exists(filename + '.xml'):
        return SDMTable(name, filename + '.xml', entityid)
    elif os.path.exists(filename + '.bin'):
        return SDMBinaryTable(name, filename + '.bin', entityid)
    else:
        raise 'Not a valid table type'

class SDMTable:
    def __init__(self, name, path, entityid):
        self.name = name
        self.path = path
        # self._tree = objectify.parse(path)
        # self._table = self._tree.getroot()
        self.entityid = entityid

class SDMBinaryTable:
    def __init__(self, name, path, entityid):
        self.name = name
        self.path = path
        self.entityid = entityid

