import argparse as ap
import os
import sys


from . import wf
from ._version import ___version___ as version


_RUN_QACLEAN_DESCRIPTION = """"""


def _make_qaclean_parser():
    r"""Command-line CIPL Launch Parser"""
    result = ap.ArgumentParser(description=_RUN_QACLEAN_DESCRIPTION.format(version),
                           formatter_class=ap.RawTextHelpFormatter)
    result.add_argument('-P', '--profile', action='store', default='',
                    help='profile name to use, e.g. dsoc-dev, dsoc-prod')
    result.add_argument('workingDirectory', type = str, action='store', nargs='+',
                        help='Working Directories to remove from the qa area.')
    return result


def launch_deletions():
    r"""Direct launch of the QaCleanupWorkflow (because SRDP)"""

    # parse our arguments, get profile and list of Ids
    args = _make_qaclean_parser().parse_args()

    # Shamelessly stolen from epilogue with a twist: allow for explict profile setting via the CL
    if 'CAPO_PROFILE' not in os.environ and '' == args.profile:
        # try to synthesize a profile from our installation root
        profile = os.path.abspath(sys.argv[0]).split(os.path.sep)[-3]
        os.environ['CAPO_PROFILE'] = profile
        print('No CAPO_PROFILE explicitly set, synthesizing {0} by path'.format(str(profile)))
    elif '' != args.profile:
        os.environ['CAPO_PROFILE'] = args.profile

    #
    # Command line we want is:
    #
    # wf -s [] -P [] -p workflowName=QaCleanup -p =arg runQaCleanupWorkflow
    #
    # The pieces of the string
    profile_name = os.environ['CAPO_PROFILE']
    if (profile_name.find('dsoc') == -1) and (profile_name.find('nm') == -1):
        # Running in CV:
        cl_basics = "-s NAASC -P "
    else:
        # Running in NM:
        cl_basics = "-s DSOC -P " # profile here
    cl_wf_args = " -p workflowName=QaCleanup -p subDirOrFileName="  #
    cl_finish = " runQaCleanupWorkflow"

    #
    # Loop over the provided fileSetIds and send a command for each,
    # waiting for the previous one to report back information before
    # starting the next.
    #
    for id in args.workingDirectory:

        wfArgs =cl_basics + profile_name + cl_wf_args + id + cl_finish
        wf(args=wfArgs.split(' '))
        print(f"Launched workflow to delete {id} from the QA areas.")
