"""
Tomcat support functions for the deployment system.
"""

import os, glob, sys
import requests
from invoke import env

DEPLOY_PATH = 'http://{}:8080/manager/text/deploy?path=/{}&update=true'


def war(c, host, module_name, **kwargs):
    """
    Deploy the war file in this module.

    Determine the war file to deploy by  assuming the Maven project hierarchy
    """
    if not os.path.exists(module_name) or os.path.isdir(module_name):
        kwargs['context'] = module_name
        module_name = glob.glob('{0}/target/{0}*.war'.format(module_name))[0]
    deploy_war(c, host, module_name, **kwargs)


def deploy_war(c, host, warfile, **kwargs):
    """
    Deploy the supplied war file.

    Optionally, you may give context as a keyword argument to change
    the deployment context from the filename to something better.
    """
    default_context = os.path.splitext(os.path.basename(warfile))[0]
    context = kwargs['context'] if 'context' in kwargs else default_context
    with open(warfile, 'rb') as f:
        url = DEPLOY_PATH.format(host, context)
        try:
            r = requests.put(url=url,
                             auth=(kwargs['username'], kwargs['password']),
                             data=f)
            if r.status_code == 200:
                print(r.text.strip())
            else:
                print(f'Error deploying warfile {warfile} to {host}/{context}')
                sys.exit(-1)
        except requests.exceptions.ConnectionError as e:
            print(f'Unable to connect to host {host} to deploy warfile {warfile} to /{context}')
            exit(1)
