"""
Interfaces used by the Workspace system.
"""

import inspect
from abc import ABC, abstractmethod
from pathlib import Path
from typing import Dict, List


class WorkflowServiceIF(ABC):
    """
    Executes workflows; should be a freestanding service.
    """
    @abstractmethod
    def execute(self, workflow_name: str, argument: Dict, files: List[Path]):
        """
        Execute this workflow against these files.

        :param workflow_name:  name of the workflow to run
        :param argument:       extra argument (a JSON object)
        :param files:          some extra files the workflow should consider
        :return:               a stream of events from this workflow
        """
        raise NotImplementedError(f'{self.__class__.__name__}.{inspect.stack()[0][3]}')


class WorkflowInfoIF(ABC):
    """
    Holds information about workflows.
    """
    @abstractmethod
    def lookup_workflow_definition(self, name: str) -> 'Workflow':
        """
        Look up the workflow with this name.

        :param name:  Workflow name
        :return:      Workflow instance
        """
        raise NotImplementedError(f'{self.__class__.__name__}.{inspect.stack()[0][3]}')
